@@ -10,8 +10,8 @@ import (
 	"net/http"
 	"path"
 
-	"github.com/stolostron/multicloud-operators-foundation/cmd/agent/app/options"
-	"github.com/stolostron/multicloud-operators-foundation/pkg/klusterlet/agent"
+	"github.com/open-cluster-management/multicloud-operators-foundation/cmd/agent/app/options"
+	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/klusterlet/agent"
 	"k8s.io/client-go/kubernetes"
 	certutil "k8s.io/client-go/util/cert"
 	"k8s.io/client-go/util/keyutil"
@@ -81,9 +81,10 @@ func InitializeTLS(s *options.AgentOptions) (*agent.TLSOptions, error) {
 }
 
 // ServeHealthProbes starts a server to check healthz and readyz probes
-func ServeHealthProbes(stop <-chan struct{}, healthProbeBindAddress string) {
+func ServeHealthProbes(stop <-chan struct{}, healthProbeBindAddress string, configCheck healthz.Checker) {
 	healthzHandler := &healthz.Handler{Checks: map[string]healthz.Checker{
 		"healthz-ping": healthz.Ping,
+		"configz-ping": configCheck,
 	}}
 	readyzHandler := &healthz.Handler{Checks: map[string]healthz.Checker{
 		"readyz-ping": healthz.Ping,
