@@ -5,8 +5,7 @@ import (
 	"os"
 	"testing"
 
-	clusterv1alapha1 "github.com/open-cluster-management/api/cluster/v1alpha1"
-	utils "github.com/stolostron/multicloud-operators-foundation/pkg/utils/clusterset"
+	utils "github.com/open-cluster-management/multicloud-operators-foundation/pkg/utils/clusterset"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/types"
@@ -30,10 +29,6 @@ func TestMain(m *testing.M) {
 		klog.Errorf("Failed adding apis to scheme, %v", err)
 		os.Exit(1)
 	}
-	if err := clusterv1alapha1.Install(scheme); err != nil {
-		klog.Errorf("Failed adding cluster v1alph1 to scheme, %v", err)
-		os.Exit(1)
-	}
 
 	if err := hivev1.AddToScheme(scheme); err != nil {
 		klog.Errorf("Failed adding hive to scheme, %v", err)
