@@ -7,6 +7,7 @@ import (
 	"net/url"
 	"os"
 	"regexp"
+	"sort"
 	"strings"
 	"time"
 
@@ -53,6 +54,13 @@ const (
 	defaultRequeueLater = 1 * time.Minute
 )
 
+// clusterDeploymentAWSPrivateLinkConditions are the cluster deployment conditions controlled by
+// AWS private link controller
+var clusterDeploymentAWSPrivateLinkConditions = []hivev1.ClusterDeploymentConditionType{
+	hivev1.AWSPrivateLinkFailedClusterDeploymentCondition,
+	hivev1.AWSPrivateLinkReadyClusterDeploymentCondition,
+}
+
 // Add creates a new AWSPrivateLink Controller and adds it to the Manager with default RBAC.
 // The Manager will set fields on the Controller and Start it when the Manager is Started.
 func Add(mgr manager.Manager) error {
@@ -100,7 +108,8 @@ func AddToManager(mgr manager.Manager, r *ReconcileAWSPrivateLink, concurrentRec
 	}
 
 	// Watch for changes to ClusterDeployment
-	err = c.Watch(&source.Kind{Type: &hivev1.ClusterDeployment{}}, &handler.EnqueueRequestForObject{})
+	err = c.Watch(&source.Kind{Type: &hivev1.ClusterDeployment{}},
+		controllerutils.NewRateLimitedUpdateEventHandler(&handler.EnqueueRequestForObject{}, controllerutils.IsClusterDeploymentErrorUpdateEvent))
 	if err != nil {
 		log.WithField("controller", ControllerName).WithError(err).Error("Error watching cluster deployment")
 		return err
@@ -163,6 +172,18 @@ func (r *ReconcileAWSPrivateLink) Reconcile(ctx context.Context, request reconci
 		return reconcile.Result{}, err
 	}
 
+	// Initialize cluster deployment conditions if not present
+	newConditions := controllerutils.InitializeClusterDeploymentConditions(cd.Status.Conditions, clusterDeploymentAWSPrivateLinkConditions)
+	if len(newConditions) > len(cd.Status.Conditions) {
+		cd.Status.Conditions = newConditions
+		logger.Info("initializing AWS private link controller conditions")
+		if err := r.Status().Update(context.TODO(), cd); err != nil {
+			logger.WithError(err).Log(controllerutils.LogLevel(err), "failed to update cluster deployment status")
+			return reconcile.Result{}, err
+		}
+		return reconcile.Result{}, nil
+	}
+
 	if cd.Spec.Platform.AWS == nil ||
 		cd.Spec.Platform.AWS.PrivateLink == nil {
 		logger.Debug("controller cannot service the clusterdeployment, so skipping")
@@ -250,14 +271,6 @@ func (r *ReconcileAWSPrivateLink) Reconcile(ctx context.Context, request reconci
 			logger.WithField("prevInfraID", *cp.Spec.PrevInfraID).
 				Info("cleaning up PrivateLink resources from previous attempt")
 
-			if err := r.setProgressCondition(cd, corev1.ConditionFalse,
-				"CleanupForProvisionReattempt",
-				"cleaning up resources from previous provision attempt so that next attempt can start",
-				logger); err != nil {
-				logger.WithError(err).Error("failed to update condition on cluster deployment")
-				return reconcile.Result{}, err
-			}
-
 			if err := r.cleanupPreviousProvisionAttempt(cd, cp, logger); err != nil {
 				logger.WithError(err).Error("error cleaning up PrivateLink resources for ClusterDeployment")
 
@@ -267,6 +280,15 @@ func (r *ReconcileAWSPrivateLink) Reconcile(ctx context.Context, request reconci
 				}
 				return reconcile.Result{}, err
 			}
+
+			if err := r.setReadyCondition(cd, corev1.ConditionFalse,
+				"PreviousAttemptCleanupComplete",
+				"successfully cleaned up resources from previous provision attempt so that next attempt can start",
+				logger); err != nil {
+				logger.WithError(err).Error("failed to update condition on cluster deployment")
+				return reconcile.Result{}, err
+			}
+
 			return reconcile.Result{Requeue: true}, nil
 		}
 	}
@@ -356,7 +378,7 @@ func (r *ReconcileAWSPrivateLink) setErrCondition(cd *hivev1.ClusterDeployment,
 	return r.Status().Update(context.TODO(), curr)
 }
 
-func (r *ReconcileAWSPrivateLink) setProgressCondition(cd *hivev1.ClusterDeployment,
+func (r *ReconcileAWSPrivateLink) setReadyCondition(cd *hivev1.ClusterDeployment,
 	completed corev1.ConditionStatus,
 	reason string, message string,
 	logger log.FieldLogger) error {
@@ -426,9 +448,9 @@ func (r *ReconcileAWSPrivateLink) reconcilePrivateLink(cd *hivev1.ClusterDeploym
 		if awsErrCodeEquals(err, "LoadBalancerNotFound") {
 			logger.WithField("infraID", clusterMetadata.InfraID).Debug("NLB is not yet created for the cluster, will retry later")
 
-			if err := r.setProgressCondition(cd, corev1.ConditionFalse,
+			if err := r.setReadyCondition(cd, corev1.ConditionFalse,
 				"DiscoveringNLBNotYetFound",
-				"discovering NLB for the cluster, but it does not exists yet",
+				"discovering NLB for the cluster, but it does not exist yet",
 				logger); err != nil {
 				logger.WithError(err).Error("failed to update condition on cluster deployment")
 				return reconcile.Result{}, err
@@ -438,7 +460,7 @@ func (r *ReconcileAWSPrivateLink) reconcilePrivateLink(cd *hivev1.ClusterDeploym
 
 		logger.WithField("infraID", clusterMetadata.InfraID).WithError(err).Error("error discovering NLB for the cluster")
 
-		if err := r.setErrCondition(cd, "DiscoveringNLBFailed", err, logger); err != nil {
+		if err := r.setErrCondition(cd, "DiscoveringNLBFailed", errors.New(controllerutils.ErrorScrub(err)), logger); err != nil {
 			logger.WithError(err).Error("failed to update condition on cluster deployment")
 			return reconcile.Result{}, err
 		}
@@ -450,14 +472,14 @@ func (r *ReconcileAWSPrivateLink) reconcilePrivateLink(cd *hivev1.ClusterDeploym
 	if err != nil {
 		logger.WithError(err).Error("failed to reconcile the VPC Endpoint Service")
 
-		if err := r.setErrCondition(cd, "VPCEndpointServiceReconcileFailed", err, logger); err != nil {
+		if err := r.setErrCondition(cd, "VPCEndpointServiceReconcileFailed", errors.New(controllerutils.ErrorScrub(err)), logger); err != nil {
 			logger.WithError(err).Error("failed to update condition on cluster deployment")
 			return reconcile.Result{}, err
 		}
 		return reconcile.Result{}, errors.Wrap(err, "failed to reconcile the VPC Endpoint Service")
 	}
 	if serviceModified {
-		if err := r.setProgressCondition(cd, corev1.ConditionFalse,
+		if err := r.setReadyCondition(cd, corev1.ConditionFalse,
 			"ReconciledVPCEndpointService",
 			"reconciled the VPC Endpoint Service for the cluster",
 			logger); err != nil {
@@ -486,7 +508,7 @@ func (r *ReconcileAWSPrivateLink) reconcilePrivateLink(cd *hivev1.ClusterDeploym
 	}
 
 	if endpointModified {
-		if err := r.setProgressCondition(cd, corev1.ConditionFalse,
+		if err := r.setReadyCondition(cd, corev1.ConditionFalse,
 			"ReconciledVPCEndpoint",
 			"reconciled the VPC Endpoint for the cluster",
 			logger); err != nil {
@@ -521,7 +543,7 @@ func (r *ReconcileAWSPrivateLink) reconcilePrivateLink(cd *hivev1.ClusterDeploym
 	}
 
 	if hzModified {
-		if err := r.setProgressCondition(cd, corev1.ConditionFalse,
+		if err := r.setReadyCondition(cd, corev1.ConditionFalse,
 			"ReconciledPrivateHostedZone",
 			"reconciled the Private Hosted Zone for the VPC Endpoint of the cluster",
 			logger); err != nil {
@@ -543,7 +565,7 @@ func (r *ReconcileAWSPrivateLink) reconcilePrivateLink(cd *hivev1.ClusterDeploym
 	}
 
 	if associationsModified {
-		if err := r.setProgressCondition(cd, corev1.ConditionFalse,
+		if err := r.setReadyCondition(cd, corev1.ConditionFalse,
 			"ReconciledAssociationsToVPCs",
 			"reconciled the associations of all the required VPCs to the Private Hosted Zone for the VPC Endpoint",
 			logger); err != nil {
@@ -552,7 +574,7 @@ func (r *ReconcileAWSPrivateLink) reconcilePrivateLink(cd *hivev1.ClusterDeploym
 		}
 	}
 
-	if err := r.setProgressCondition(cd, corev1.ConditionTrue,
+	if err := r.setReadyCondition(cd, corev1.ConditionTrue,
 		"PrivateLinkAccessReady",
 		"private link access is ready for use",
 		logger); err != nil {
@@ -864,35 +886,74 @@ func (r *ReconcileAWSPrivateLink) reconcileHostedZone(awsClient *awsClient,
 
 	hzLog := logger.WithField("hostedZoneID", hostedZoneID)
 
-	endpointDNSName := vpcEndpoint.DnsEntries[0].DnsName
-	endpointDNSHostedZone := vpcEndpoint.DnsEntries[0].HostedZoneId
+	rSet, err := r.recordSet(awsClient.hub, apiDomain, vpcEndpoint)
+	if err != nil {
+		hzLog.WithField("vpcEndpoint", aws.StringValue(vpcEndpoint.VpcEndpointId)).
+			WithError(err).Error("error generating DNS records")
+		return modified, "", err
+	}
 
 	_, err = awsClient.hub.ChangeResourceRecordSets(&route53.ChangeResourceRecordSetsInput{
 		HostedZoneId: aws.String(hostedZoneID),
 		ChangeBatch: &route53.ChangeBatch{
 			Changes: []*route53.Change{{
-				Action: aws.String(route53.ChangeActionUpsert),
-				ResourceRecordSet: &route53.ResourceRecordSet{
-					Type: aws.String("A"),
-					AliasTarget: &route53.AliasTarget{
-						DNSName:              endpointDNSName,
-						HostedZoneId:         endpointDNSHostedZone,
-						EvaluateTargetHealth: aws.Bool(false),
-					},
-					Name: aws.String(apiDomain),
-				},
+				Action:            aws.String(route53.ChangeActionUpsert),
+				ResourceRecordSet: rSet,
 			}},
 		},
 	})
 	if err != nil {
-		hzLog.WithField("aliasDNSName", endpointDNSName).
-			WithField("aliasHostedZone", endpointDNSHostedZone).
-			WithError(err).Error("error add record to Hosted Zone for VPC Endpoint")
+		hzLog.WithError(err).Error("error adding record to Hosted Zone for VPC Endpoint")
 		return modified, "", err
 	}
 	return modified, hostedZoneID, nil
 }
 
+func (r *ReconcileAWSPrivateLink) recordSet(awsClient awsclient.Client, apiDomain string, vpcEndpoint *ec2.VpcEndpoint) (*route53.ResourceRecordSet, error) {
+	rSet := &route53.ResourceRecordSet{
+		Name: aws.String(apiDomain),
+	}
+	switch r.controllerconfig.DNSRecordType {
+	case hivev1.ARecordAWSPrivateLinkDNSRecordType:
+		rSet.Type = aws.String("A")
+		rSet.TTL = aws.Int64(10)
+
+		// get the ips from the elastic networking interfaces attached to the VPC endpoint
+		enis := vpcEndpoint.NetworkInterfaceIds
+		if len(enis) == 0 {
+			return nil, errors.New("No network interfaces attached to the vpc endpoint")
+		}
+		res, err := awsClient.DescribeNetworkInterfaces(&ec2.DescribeNetworkInterfacesInput{NetworkInterfaceIds: vpcEndpoint.NetworkInterfaceIds})
+		if err != nil {
+			return nil, errors.Wrap(err, "failed to list network interfaces attached to the vpc endpoint")
+		}
+		if len(res.NetworkInterfaces) == 0 {
+			return nil, errors.New("No network interfaces attached to the vpc endpoint")
+		}
+
+		var ips []string
+		for _, eni := range res.NetworkInterfaces {
+			ips = append(ips, aws.StringValue(eni.PrivateIpAddress))
+		}
+		sort.Strings(ips)
+
+		for _, ip := range ips {
+			rSet.ResourceRecords = append(rSet.ResourceRecords, &route53.ResourceRecord{
+				Value: aws.String(ip),
+			})
+		}
+
+	default: // Alias is the default case.
+		rSet.Type = aws.String("A")
+		rSet.AliasTarget = &route53.AliasTarget{
+			DNSName:              vpcEndpoint.DnsEntries[0].DnsName,
+			HostedZoneId:         vpcEndpoint.DnsEntries[0].HostedZoneId,
+			EvaluateTargetHealth: aws.Bool(false),
+		}
+	}
+	return rSet, nil
+}
+
 func (r *ReconcileAWSPrivateLink) ensureHostedZone(awsClient awsclient.Client,
 	cd *hivev1.ClusterDeployment,
 	endpoint *ec2.VpcEndpoint, apiDomain string,
@@ -1185,7 +1246,7 @@ func initialURL(c client.Client, key client.ObjectKey) (string, error) {
 		key,
 		kubeconfigSecret,
 	); err != nil {
-		return "", errors.Wrap(err, "could not get admin kubeconfig secret")
+		return "", err
 	}
 	cfg, err := restConfigFromSecret(kubeconfigSecret)
 	if err != nil {
